@@ -43,6 +43,33 @@ from cdist import core, inventory
 from cdist.util.remoteutil import inspect_ssh_mux_opts
 
 
+def graph_check_cycle(graph):
+    # Start from each node in the graph and check for cycle starting from it.
+    for node in graph:
+        # Cycle path.
+        path = [node]
+        has_cycle = _graph_dfs_cycle(graph, node, path)
+        if has_cycle:
+            return has_cycle, path
+    return False, None
+
+
+def _graph_dfs_cycle(graph, node, path):
+    for neighbour in graph.get(node, ()):
+        # If node is already in path then this is cycle.
+        if neighbour in path:
+            path.append(neighbour)
+            return True
+        path.append(neighbour)
+        rv = _graph_dfs_cycle(graph, neighbour, path)
+        if rv:
+            return True
+        # Remove last item from list - neighbour whose DFS path we have have
+        # just checked.
+        del path[-1]
+    return False
+
+
 class Config(object):
     """Cdist main class to hold arbitrary data"""
 
@@ -77,9 +104,12 @@ class Config(object):
         self.remove_remote_files_dirs = remove_remote_files_dirs
 
         self.explorer = core.Explorer(self.local.target_host, self.local,
-                                      self.remote, jobs=self.jobs)
-        self.manifest = core.Manifest(self.local.target_host, self.local)
-        self.code = core.Code(self.local.target_host, self.local, self.remote)
+                                      self.remote, jobs=self.jobs,
+                                      dry_run=self.dry_run)
+        self.manifest = core.Manifest(self.local.target_host, self.local,
+                                      dry_run=self.dry_run)
+        self.code = core.Code(self.local.target_host, self.local, self.remote,
+                              dry_run=self.dry_run)
 
     def _init_files_dirs(self):
         """Prepare files and directories for the run"""
@@ -254,14 +284,14 @@ class Config(object):
                     cls.onehost(host, host_tags, host_base_path, hostdir,
                                 args, parallel=False,
                                 configuration=configuration)
-                except cdist.Error as e:
+                except cdist.Error:
                     failed_hosts.append(host)
         if args.parallel and len(process_args) == 1:
             log.debug("Only 1 host for parallel processing, doing it "
                       "sequentially")
             try:
                 cls.onehost(*process_args[0])
-            except cdist.Error as e:
+            except cdist.Error:
                 failed_hosts.append(host)
         elif args.parallel:
             log.trace("Multiprocessing start method is {}".format(
@@ -653,6 +683,28 @@ class Config(object):
         self.__dict__.update(state)
         self._open_logger()
 
+    def _validate_dependencies(self):
+        '''
+            Build dependency graph for unfinished objects and
+            check for cycles.
+        '''
+        graph = {}
+        for cdist_object in self.object_list():
+            obj_name = cdist_object.name
+            if obj_name not in graph:
+                graph[obj_name] = []
+            if cdist_object.state == cdist_object.STATE_DONE:
+                continue
+
+            for requirement in cdist_object.requirements_unfinished(
+                    cdist_object.requirements):
+                graph[obj_name].append(requirement.name)
+
+            for requirement in cdist_object.requirements_unfinished(
+                    cdist_object.autorequire):
+                graph[obj_name].append(requirement.name)
+        return graph_check_cycle(graph)
+
     def iterate_until_finished(self):
         """
             Go through all objects and solve them
@@ -662,6 +714,12 @@ class Config(object):
         objects_changed = True
 
         while objects_changed:
+            # Check for cycles as early as possible.
+            has_cycle, path = self._validate_dependencies()
+            if has_cycle:
+                raise cdist.UnresolvableRequirementsError(
+                    "Cycle detected in object dependencies:\n{}!".format(
+                        " -> ".join(path)))
             objects_changed = self.iterate_once()
 
         # Check whether all objects have been finished
@@ -700,14 +758,34 @@ class Config(object):
                     ("The requirements of the following objects could not be "
                      "resolved:\n%s") % ("\n".join(info_string)))
 
+    def _handle_deprecation(self, cdist_object):
+        cdist_type = cdist_object.cdist_type
+        deprecated = cdist_type.deprecated
+        if deprecated is not None:
+            if deprecated:
+                self.log.warning("Type %s is deprecated: %s", cdist_type.name,
+                                 deprecated)
+            else:
+                self.log.warning("Type %s is deprecated.", cdist_type.name)
+        for param in cdist_object.parameters:
+            if param in cdist_type.deprecated_parameters:
+                msg = cdist_type.deprecated_parameters[param]
+                if msg:
+                    format = "%s parameter of type %s is deprecated: %s"
+                    args = [param, cdist_type.name, msg]
+                else:
+                    format = "%s parameter of type %s is deprecated."
+                    args = [param, cdist_type.name]
+                self.log.warning(format, *args)
+
     def object_prepare(self, cdist_object, transfer_type_explorers=True):
         """Prepare object: Run type explorer + manifest"""
+        self._handle_deprecation(cdist_object)
+        self.log.verbose("Preparing object {}".format(cdist_object.name))
+        self.log.verbose(
+            "Running manifest and explorers for " + cdist_object.name)
+        self.explorer.run_type_explorers(cdist_object, transfer_type_explorers)
         try:
-            self.log.verbose("Preparing object {}".format(cdist_object.name))
-            self.log.verbose(
-                    "Running manifest and explorers for " + cdist_object.name)
-            self.explorer.run_type_explorers(cdist_object,
-                                             transfer_type_explorers)
             self.manifest.run_type_manifest(cdist_object)
             cdist_object.state = core.CdistObject.STATE_PREPARED
         except cdist.Error as e:
